<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-porte_plume?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// P
	'porte_plume_description' => 'Porte plume - расширение возможностей стандартного текстового редактора SPIP. Использует javascript библиотеку  [MarkItUp->http://markitup.jaysalvat.com/home/].',
	'porte_plume_nom' => 'Панель инструментов (Porte plume)',
	'porte_plume_slogan' => 'Дополнительные возможности для текстового редактора',
];
